@@ -3,6 +3,7 @@
   <head>
     <title><?php  print $print["title"] ?></title>
     <?php  print $print["head"] ?>
+    <?php  print $print["scripts"] ?>
     <?php  print $print["robots_meta"] ?>
     <?php  print $print["base_href"] ?>
     <?php  print $print["favicon"] ?>
@@ -11,12 +12,15 @@
   <body<?php  print $print["sendtoprinter"] ?>>
     <div><?php  print $print["logo"] ?></div>
     <div class="print-site_name"><?php  print $print["site_name"] ?></div>
+    <p />
+    <div class="print-breadcrumb"><?php  print $print["breadcrumb"] ?></div>
+    <hr class="print-hr" />
     <div class="print-title"><?php  print $print["title"] ?></div>
     <div class="print-submitted"><?php  print $print["submitted"] ?></div>
     <div class="print-created"><?php  print $print["created"] ?></div>
     <p />
     <div class="print-taxonomy"><?php print $print["taxonomy"] ?></div>
-    <div class="print-content"><?php  print $node->body; ?></div>
+    <div class="print-content"><?php  print $print["content"] ?></div>
     <div class="print-footer"><?php  print $print["footer_message"] ?></div>
     <hr class="print-hr" />
     <div class="print-source_url"><?php  print $print["source_url"] ?></div>
